@@ -67,12 +67,10 @@ struct NautilusBookmarkClass {
 typedef struct NautilusBookmarkClass NautilusBookmarkClass;
 
 GType                 nautilus_bookmark_get_type               (void);
-NautilusBookmark *    nautilus_bookmark_new                    (GFile                 *location,
-								const char            *name);
-NautilusBookmark *    nautilus_bookmark_new_with_icon          (GFile                 *location,
-								const char            *name,
-								gboolean	       has_custom_name,
-								GIcon                 *icon);
+NautilusBookmark *    nautilus_bookmark_new                    (GFile *location,
+                                                                const char *name,
+                                                                gboolean has_custom_name,
+                                                                GIcon *icon);
 NautilusBookmark *    nautilus_bookmark_copy                   (NautilusBookmark      *bookmark);
 char *                nautilus_bookmark_get_name               (NautilusBookmark      *bookmark);
 GFile *               nautilus_bookmark_get_location           (NautilusBookmark      *bookmark);
@@ -80,9 +78,7 @@ char *                nautilus_bookmark_get_uri                (NautilusBookmark
 GIcon *               nautilus_bookmark_get_icon               (NautilusBookmark      *bookmark);
 gboolean	      nautilus_bookmark_get_has_custom_name    (NautilusBookmark      *bookmark);		
 gboolean              nautilus_bookmark_set_name               (NautilusBookmark      *bookmark,
-								const char            *new_name);
-void		      nautilus_bookmark_set_has_custom_name    (NautilusBookmark      *bookmark,
-							        gboolean	       has_custom_name);		
+								const char            *new_name);		
 gboolean              nautilus_bookmark_uri_known_not_to_exist (NautilusBookmark      *bookmark);
 int                   nautilus_bookmark_compare_with           (gconstpointer          a,
 								gconstpointer          b);
