@@ -84,6 +84,7 @@ static void     fm_desktop_icon_view_init                   (FMDesktopIconView
 static void     fm_desktop_icon_view_class_init             (FMDesktopIconViewClass *klass);
 static void     default_zoom_level_changed                        (gpointer                user_data);
 static gboolean real_supports_auto_layout                         (FMIconView             *view);
+static gboolean real_supports_scaling	                          (FMIconView             *view);
 static gboolean real_supports_keep_aligned                        (FMIconView             *view);
 static gboolean real_supports_labels_beside_icons                 (FMIconView             *view);
 static void     real_merge_menus                                  (FMDirectoryView        *view);
@@ -315,6 +316,7 @@ fm_desktop_icon_view_class_init (FMDesktopIconViewClass *class)
 	FM_DIRECTORY_VIEW_CLASS (class)->supports_zooming = real_supports_zooming;
 
 	FM_ICON_VIEW_CLASS (class)->supports_auto_layout = real_supports_auto_layout;
+	FM_ICON_VIEW_CLASS (class)->supports_scaling = real_supports_scaling;
 	FM_ICON_VIEW_CLASS (class)->supports_keep_aligned = real_supports_keep_aligned;
 	FM_ICON_VIEW_CLASS (class)->supports_labels_beside_icons = real_supports_labels_beside_icons;
 }
@@ -778,6 +780,12 @@ real_supports_auto_layout (FMIconView *view)
 	return FALSE;
 }
 
+static gboolean
+real_supports_scaling (FMIconView *view)
+{
+	return TRUE;
+}
+
 static gboolean
 real_supports_keep_aligned (FMIconView *view)
 {
