@@ -328,18 +328,22 @@ nautilus_location_entry_activate (GtkEntry *entry)
 {
 	NautilusLocationEntry *loc_entry;
 	const gchar *entry_text;
-	gchar *full_path;
+	gchar *full_path, *uri_scheme = NULL;
 
 	loc_entry = NAUTILUS_LOCATION_ENTRY (entry);
 	entry_text = gtk_entry_get_text (entry);
 
 	if (entry_text != NULL && *entry_text != '\0') {
-		if (!g_path_is_absolute (entry_text)) {
+		uri_scheme = g_uri_parse_scheme (entry_text);
+
+		if (!g_path_is_absolute (entry_text) && uri_scheme == NULL) {
 			/* Fix non absolute paths */
 			full_path = g_build_filename (loc_entry->details->current_directory, entry_text, NULL);
 			gtk_entry_set_text (entry, full_path);
 			g_free (full_path);
 		}
+
+		g_free (uri_scheme);
 	}
 
 	EEL_CALL_PARENT (GTK_ENTRY_CLASS, activate, (entry));
