@@ -1,3 +1,4 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* nautilus-pathbar.c
  * Copyright (C) 2004  Red Hat, Inc.,  Jonathan Blandford <jrb@gnome.org>
  *
@@ -826,7 +827,7 @@ nautilus_path_bar_remove (GtkContainer *container,
                 if (widget == BUTTON_DATA (children->data)->button) {
 			nautilus_path_bar_remove_1 (container, widget);
 	  		path_bar->button_list = g_list_remove_link (path_bar->button_list, children);
-	  		g_list_free (children);
+	  		g_list_free_1 (children);
 	  		return;
 		}
                 children = children->next;
@@ -1569,11 +1570,19 @@ button_data_file_changed (NautilusFile *file,
 		}
 	} else if (nautilus_file_is_gone (file)) {
 		/* remove this and the following buttons */
-		g_assert (g_list_find (path_bar->button_list, button_data));
-		while ((temp_button_data = g_list_last (path_bar->button_list)->data) != button_data) {
+		GList *children;
+
+		children = g_list_find (path_bar->button_list, button_data);
+
+		while (children != NULL) {
+			temp_button_data = children->data;
+
+			/* children are in reverse order */
+			children = children->prev;
+
 			gtk_container_remove (GTK_CONTAINER (path_bar), temp_button_data->button);
 		}
-		gtk_container_remove (GTK_CONTAINER (path_bar), button_data->button);
+
 		g_object_unref (location);
 		return;
 	}
